(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     38033,        776]
NotebookOptionsPosition[     38060,        758]
NotebookOutlinePosition[     38780,        783]
CellTagsIndexPosition[     38737,        780]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Tensile Test\n",
 StyleBox["Qingchang Liu, Baoxing Xu and Marek-Jerzy Pindera\nUniversity of \
Virginia, 2018-02-01",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center,
 ExpressionUUID -> "1f0b3856-036c-4559-ac86-a359a58bd3e2"],

Cell[TextData[{
 "The strength of a material depends on its ability to sustain a load without \
undue deformation or failure. This property is inherent in the material \
itself and must be determined by ",
 StyleBox["experiment",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ". One of the most important tests to perform in this regard is the ",
 StyleBox["tensile test",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ". It is primarily to determine the relationship between the average ",
 StyleBox["normal stress",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " and average ",
 StyleBox["normal strain",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ".\nWe can determine the nominal or engineering stress by dividing the \
applied load P by the specimen\[CloseCurlyQuote]s original cross-sectional \
area ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "0"], TraditionalForm]],
  ExpressionUUID -> "9f3b00a9-8a68-4e19-b650-b9273e5f1f4e"],
 ". This calculation assumes that the stress is constant over the cross \
section and throughout the gauge length. We have"
}], "Text",
 ExpressionUUID -> "50edfe98-c88f-49cd-b9d2-e658b33bf322"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"\[Sigma]", "=", 
   FractionBox["P", 
    SubscriptBox["A", "0"]]}], TraditionalForm]],
 ExpressionUUID -> "10587da1-5bf1-4315-a704-a4ef00216d89"]], "Text",
 TextAlignment->Center],

Cell[TextData[{
 "Likewise, the nominal or engineering strain is found directly from the \
strain gauge reading, or by dividing the change in the specimen\
\[CloseCurlyQuote]s gauge length, \[Delta] , by the \
specimen\[CloseCurlyQuote]s original gauge length ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "0"], TraditionalForm]],
  ExpressionUUID -> "fb6f4045-0b7b-40c9-b5d6-809f514ccd66"],
 ". Here the strain is assumed to be constant throughout the region between \
the gauge points. Thus"
}], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"\[CurlyEpsilon]", "=", 
   FractionBox["\[Delta]", 
    SubscriptBox["L", "0"]]}], TraditionalForm]],
 ExpressionUUID -> "2feab166-284e-4113-88e9-6d242b3425d7"]], "Text",
 TextAlignment->Center],

Cell[TextData[{
 "If the corresponding values of \[Sigma] and \[CurlyEpsilon] are plotted so \
that the vertical axis is the stress and the horizontal axis is the strain, \
the resulting curve is called a ",
 StyleBox["conventional stress-strain diagram",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{D$$ = 0.0001, $CellContext`UL$$ = 0, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[D$$], 0.0001, 
       Row[{
        "\!\(\*\nStyleBox[\"Elongation\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Strain\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"in\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"the\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Bar\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"\
\[CurlyEpsilon]\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"\[CapitalDelta]L\", \"0\"],\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"/\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"L\", \"0\"],\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)", 
         Spacer[50]}]}, 1.*^-6, 0.1}, {{
       Hold[$CellContext`UL$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[\"Percentage\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"of\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Unloading\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"%\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
         Spacer[100]}]}, 0, 100}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {620., {182., 190.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, D$2612856$$ = 
    0, $CellContext`UL$2612857$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, "Variables" :> {D$$ = 0.0001, $CellContext`UL$$ = 0}, 
      "ControllerVariables" :> {
        Hold[D$$, D$2612856$$, 0], 
        Hold[$CellContext`UL$$, $CellContext`UL$2612857$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, 
         E$, $CellContext`G$, $CellContext`A$, $CellContext`L$, \
$CellContext`W$, $CellContext`Lp$, $CellContext`Wp$, $CellContext`Lu$, \
$CellContext`Wu$, $CellContext`sigma$, $CellContext`epsilon$, \
$CellContext`epl$, $CellContext`eel$, $CellContext`eyd$, $CellContext`ehd$, \
$CellContext`miu$, $CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$, $CellContext`dwf10$, \
$CellContext`dwf11$, $CellContext`dwf12$, $CellContext`dwf13$}, \
$CellContext`size$ = 10; 
        E$ = 10000; $CellContext`L$ = 
         10; $CellContext`Lp$ = $CellContext`L$ (1 + 
           2 D$$); $CellContext`miu$ = 0.4; $CellContext`W$ = 
         2; $CellContext`Wp$ = $CellContext`W$ (1 - ($CellContext`miu$ 2) 
           D$$); $CellContext`sigma$ = If[D$$ < $CellContext`epl$, E$ D$$, 
           If[
            And[D$$ >= $CellContext`epl$, D$$ < $CellContext`eyd$], 
            5 Sin[((D$$ - $CellContext`epl$)/0.05) Pi] + E$ $CellContext`epl$, 
            If[
             And[D$$ >= $CellContext`eyd$, D$$ < $CellContext`ehd$], 
             30 Sin[(((D$$ - $CellContext`eyd$)/0.18) 2) Pi] + 
             E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi], 
             50 Cos[((D$$ - $CellContext`ehd$)/0.1) Pi] - 50 + 
             30 Sin[((($CellContext`ehd$ - $CellContext`eyd$)/0.18) 2) Pi] + 
             E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) 
                Pi]]]]; $CellContext`epsilon$ = $CellContext`sigma$/
          E$; $CellContext`Lu$ = $CellContext`L$ (1 + 
           2 (D$$ - $CellContext`epsilon$ ($CellContext`UL$$/
              100))); $CellContext`Wu$ = $CellContext`W$ (
           1 - ($CellContext`miu$ 2) (
            D$$ - $CellContext`epsilon$ ($CellContext`UL$$/
             100))); $CellContext`epl$ = 0.01; $CellContext`eel$ = 
         0.012; $CellContext`eyd$ = 0.03; $CellContext`ehd$ = 
         0.075; $CellContext`dwf0$ = {
           If[$CellContext`UL$$ == 0, 
            Opacity[1], 
            Opacity[0]], Gray, 
           
           Rectangle[{0 - $CellContext`Wp$/2, (-$CellContext`Lp$)/2}, {
            0 + $CellContext`Wp$/2, $CellContext`Lp$/2}], 
           
           Rectangle[{0 - $CellContext`W$, $CellContext`Lp$/2}, {
            0 + $CellContext`W$, $CellContext`Lp$/2 + $CellContext`L$/3}], 
           
           Rectangle[{0 - $CellContext`W$, (-$CellContext`Lp$)/2}, {
            0 + $CellContext`W$, (-$CellContext`Lp$)/2 - $CellContext`L$/3}], 
           White, 
           If[D$$ == 0.1, 
            
            Rectangle[{0 - $CellContext`Wp$/2, (-$CellContext`L$)/100}, {
             0 + $CellContext`Wp$/2, $CellContext`L$/100}]], 
           
           Disk[{0 + $CellContext`W$, $CellContext`Lp$/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           
           Disk[{0 + $CellContext`W$, (-$CellContext`Lp$)/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           
           Disk[{0 - $CellContext`W$, $CellContext`Lp$/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           
           Disk[{0 - $CellContext`W$, (-$CellContext`Lp$)/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           If[D$$ > $CellContext`ehd$, 
            
            Disk[{0 + $CellContext`Wp$, 0}, {
             0.8 (1 + 4.5 D$$), 1.1 (1 + D$$)}]], 
           If[D$$ > $CellContext`ehd$, 
            
            Disk[{0 - $CellContext`Wp$, 0}, {
             0.8 (1 + 4.5 D$$), 1.1 (1 + D$$)}]], Red, 
           Arrowheads[0.15], 
           Thickness[0.025], 
           
           Arrow[{{0, $CellContext`Lp$/2 + $CellContext`L$/3}, {
             0, $CellContext`Lp$/2 + ($CellContext`L$/3) (1 + 8 D$$)}}], 
           
           Arrow[{{0, (-$CellContext`Lp$)/2 - $CellContext`L$/3}, {
             0, (-$CellContext`Lp$)/2 - ($CellContext`L$/3) (1 + 
               8 D$$)}}]}; $CellContext`dwf1$ = {
           Opacity[$CellContext`UL$$], LightGray, 
           
           Rectangle[{0 - $CellContext`Wp$/2, (-$CellContext`Lp$)/2}, {
            0 + $CellContext`Wp$/2, $CellContext`Lp$/2}], 
           
           Rectangle[{0 - $CellContext`W$, $CellContext`Lp$/2}, {
            0 + $CellContext`W$, $CellContext`Lp$/2 + $CellContext`L$/3}], 
           
           Rectangle[{0 - $CellContext`W$, (-$CellContext`Lp$)/2}, {
            0 + $CellContext`W$, (-$CellContext`Lp$)/2 - $CellContext`L$/3}], 
           White, 
           If[D$$ == 0.1, 
            
            Rectangle[{0 - $CellContext`Wp$/2, (-$CellContext`L$)/100}, {
             0 + $CellContext`Wp$/2, $CellContext`L$/100}]], 
           
           Disk[{0 + $CellContext`W$, $CellContext`Lp$/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           
           Disk[{0 + $CellContext`W$, (-$CellContext`Lp$)/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           
           Disk[{0 - $CellContext`W$, $CellContext`Lp$/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           
           Disk[{0 - $CellContext`W$, (-$CellContext`Lp$)/
             2}, $CellContext`W$ - $CellContext`Wp$/2], 
           If[D$$ > $CellContext`ehd$, 
            
            Disk[{0 + $CellContext`Wp$, 0}, {
             0.8 (1 + 4.5 D$$), 1.1 (1 + D$$)}]], 
           If[D$$ > $CellContext`ehd$, 
            
            Disk[{0 - $CellContext`Wp$, 0}, {
             0.8 (1 + 4.5 D$$), 1.1 (1 + D$$)}]]}; $CellContext`dwf2$ = 
         If[D$$ < 0.1, {
            If[$CellContext`UL$$ == 0, 
             Opacity[0], 
             Opacity[1]], Gray, 
            
            Rectangle[{0 - $CellContext`Wu$/2, (-$CellContext`Lu$)/2}, {
             0 + $CellContext`Wu$/2, $CellContext`Lu$/2}], 
            
            Rectangle[{0 - $CellContext`Wu$, $CellContext`Lu$/2}, {
             0 + $CellContext`Wu$, $CellContext`Lu$/2 + $CellContext`Lu$/3}], 
            Rectangle[{0 - $CellContext`Wu$, (-$CellContext`Lu$)/2}, {
             0 + $CellContext`Wu$, (-$CellContext`Lu$)/2 - $CellContext`Lu$/
              3}], White, 
            
            Disk[{0 + $CellContext`Wu$, $CellContext`Lu$/
              2}, $CellContext`Wu$ - $CellContext`Wu$/2], 
            
            Disk[{0 + $CellContext`Wu$, (-$CellContext`Lu$)/
              2}, $CellContext`Wu$ - $CellContext`Wu$/2], 
            
            Disk[{0 - $CellContext`Wu$, $CellContext`Lu$/
              2}, $CellContext`Wu$ - $CellContext`Wu$/2], 
            
            Disk[{0 - $CellContext`Wu$, (-$CellContext`Lu$)/
              2}, $CellContext`Wu$ - $CellContext`Wu$/2], 
            If[D$$ > $CellContext`ehd$, 
             
             Disk[{0 + $CellContext`Wu$, 0}, {
              0.8 (1 + 4.5 (
                  D$$ - $CellContext`epsilon$ ($CellContext`UL$$/100))), 
               1.1 (1 + (
                 D$$ - $CellContext`epsilon$ ($CellContext`UL$$/100)))}]], 
            If[D$$ > $CellContext`ehd$, 
             
             Disk[{0 - $CellContext`Wu$, 0}, {
              0.8 (1 + 4.5 (
                  D$$ - $CellContext`epsilon$ ($CellContext`UL$$/100))), 
               1.1 (1 + (
                 D$$ - $CellContext`epsilon$ ($CellContext`UL$$/100)))}]]}, {
           Gray, 
            
            Rectangle[{0 - $CellContext`Wp$/2, (-$CellContext`Lp$)/2}, {
             0 + $CellContext`Wp$/2, $CellContext`Lp$/2}], 
            
            Rectangle[{0 - $CellContext`W$, $CellContext`Lp$/2}, {
             0 + $CellContext`W$, $CellContext`Lp$/2 + $CellContext`L$/3}], 
            
            Rectangle[{0 - $CellContext`W$, (-$CellContext`Lp$)/2}, {
             0 + $CellContext`W$, (-$CellContext`Lp$)/2 - $CellContext`L$/3}],
             White, 
            If[D$$ == 0.1, 
             
             Rectangle[{0 - $CellContext`Wp$/2, (-$CellContext`L$)/100}, {
              0 + $CellContext`Wp$/2, $CellContext`L$/100}]], 
            
            Disk[{0 + $CellContext`W$, $CellContext`Lp$/
              2}, $CellContext`W$ - $CellContext`Wp$/2], 
            
            Disk[{0 + $CellContext`W$, (-$CellContext`Lp$)/
              2}, $CellContext`W$ - $CellContext`Wp$/2], 
            
            Disk[{0 - $CellContext`W$, $CellContext`Lp$/
              2}, $CellContext`W$ - $CellContext`Wp$/2], 
            Disk[{
             0 - $CellContext`W$, (-$CellContext`Lp$)/
              2}, $CellContext`W$ - $CellContext`Wp$/2], 
            If[D$$ > $CellContext`ehd$, 
             
             Disk[{0 + $CellContext`Wp$, 0}, {
              0.8 (1 + 4.5 D$$), 1.1 (1 + D$$)}]], 
            If[D$$ > $CellContext`ehd$, 
             
             Disk[{0 - $CellContext`Wp$, 0}, {
              0.8 (1 + 4.5 D$$), 1.1 (1 + D$$)}]], Red, 
            Arrowheads[0.15], 
            Thickness[0.025], 
            
            Arrow[{{0, $CellContext`Lp$/2 + $CellContext`L$/3}, {
              0, $CellContext`Lp$/2 + ($CellContext`L$/3) (1 + 8 D$$)}}], 
            
            Arrow[{{0, (-$CellContext`Lp$)/2 - $CellContext`L$/3}, {
              0, (-$CellContext`Lp$)/2 - ($CellContext`L$/3) (1 + 
                8 D$$)}}]}]; $CellContext`dwf3$ = {
           Plot[
           E$ $CellContext`x, {$CellContext`x, 0, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, 
            AxesLabel -> {
             "\!\(\*\nStyleBox[\"\[CurlyEpsilon]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
              "\!\(\*\nStyleBox[\"\[Sigma]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> Yellow]}; $CellContext`dwf4$ = {
           Plot[
           E$ $CellContext`x, {$CellContext`x, 0, $CellContext`epl$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, 
            AxesLabel -> {
             "\!\(\*\nStyleBox[\"\[CurlyEpsilon]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
              "\!\(\*\nStyleBox[\"\[Sigma]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> Yellow], 
           Plot[
           Sin[((($CellContext`x - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`epl$, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> Yellow]}; $CellContext`dwf5$ = {
           Plot[
           E$ $CellContext`x, {$CellContext`x, 0, $CellContext`epl$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, 
            AxesLabel -> {
             "\!\(\*\nStyleBox[\"\[CurlyEpsilon]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
              "\!\(\*\nStyleBox[\"\[Sigma]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> Yellow], 
           Plot[
           Sin[((($CellContext`x - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`epl$, \
$CellContext`eel$}, Axes -> {{True, False}, {True, False}}, 
            AxesOrigin -> {0, 0}, ImageSize -> {300, 150}, PlotStyle -> Blue, 
            Filling -> Axis, FillingStyle -> Yellow], 
           Plot[
           5 Sin[(($CellContext`x - $CellContext`eel$)/0.05) Pi] + 
            Sin[((($CellContext`eel$ - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`eel$, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> LightRed]}; $CellContext`dwf6$ = {
           Plot[
           E$ $CellContext`x, {$CellContext`x, 0, $CellContext`epl$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, 
            AxesLabel -> {
             "\!\(\*\nStyleBox[\"\[CurlyEpsilon]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
              "\!\(\*\nStyleBox[\"\[Sigma]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> Yellow], 
           Plot[
           Sin[((($CellContext`x - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`epl$, \
$CellContext`eel$}, Axes -> {{True, False}, {True, False}}, 
            AxesOrigin -> {0, 0}, ImageSize -> {300, 150}, PlotStyle -> 
            LightBlue, Filling -> Axis, FillingStyle -> Yellow], 
           Plot[
           5 Sin[(($CellContext`x - $CellContext`eel$)/0.05) Pi] + 
            Sin[((($CellContext`eel$ - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`eel$, \
$CellContext`eyd$}, Axes -> {{True, False}, {True, False}}, 
            AxesOrigin -> {0, 0}, ImageSize -> {300, 150}, PlotStyle -> Blue, 
            Filling -> Axis, FillingStyle -> LightRed], 
           Plot[
           30 Sin[((($CellContext`x - $CellContext`eyd$)/0.18) 2) Pi] + 
            Sin[((($CellContext`eel$ - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$ + 
            5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) 
               Pi], {$CellContext`x, $CellContext`eyd$, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> LightBlue], 
           Plot[
           10 Sin[(($CellContext`x - $CellContext`eyd$)/0.05) Pi] + 
            E$ (($CellContext`x - $CellContext`eyd$)/10) + 
            E$ $CellContext`epl$ + 
            5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) 
               Pi], {$CellContext`x, $CellContext`eyd$, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            Ticks -> {{0, 0.05, 0.1}, {50, 100, 150}}, 
            ImageSize -> {300, 150}, 
            PlotStyle -> {Blue, Dashed}]}; $CellContext`dwf7$ = {
           Plot[
           E$ $CellContext`x, {$CellContext`x, 0, $CellContext`epl$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, 
            AxesLabel -> {
             "\!\(\*\nStyleBox[\"\[CurlyEpsilon]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)", 
              "\!\(\*\nStyleBox[\"\[Sigma]\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)"}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> Yellow], 
           Plot[
           Sin[((($CellContext`x - $CellContext`epl$)/0.01) 2) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`epl$, \
$CellContext`eel$}, Axes -> {{True, False}, {True, False}}, 
            AxesOrigin -> {0, 0}, ImageSize -> {300, 150}, PlotStyle -> Blue, 
            Filling -> Axis, FillingStyle -> Yellow], 
           Plot[
           5 Sin[(($CellContext`x - $CellContext`eel$)/0.05) Pi] + 
            E$ $CellContext`epl$, {$CellContext`x, $CellContext`eel$, \
$CellContext`eyd$}, Axes -> {{True, False}, {True, False}}, 
            AxesOrigin -> {0, 0}, ImageSize -> {300, 150}, PlotStyle -> Blue, 
            Filling -> Axis, FillingStyle -> LightRed], 
           Plot[
           30 Sin[((($CellContext`x - $CellContext`eyd$)/0.18) 2) Pi] + 
            E$ $CellContext`epl$ + 
            5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) 
               Pi], {$CellContext`x, $CellContext`eyd$, $CellContext`ehd$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            ImageSize -> {300, 150}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> LightBlue], 
           Plot[
           50 Cos[(($CellContext`x - $CellContext`ehd$)/0.1) Pi] - 50 + 
            30 Sin[((($CellContext`ehd$ - $CellContext`eyd$)/0.18) 2) Pi] + 
            E$ $CellContext`epl$ + 
            5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) 
               Pi], {$CellContext`x, $CellContext`ehd$, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            Ticks -> {{0, 0.05, 0.1}, {50, 100, 150}}, 
            ImageSize -> {300, 150}, PlotStyle -> Blue, Filling -> Axis, 
            FillingStyle -> LightGreen], 
           Plot[
           10 Sin[(($CellContext`x - $CellContext`eyd$)/0.05) Pi] + 
            E$ (($CellContext`x - $CellContext`eyd$)/10) + 
            E$ $CellContext`epl$ + 
            5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) 
               Pi], {$CellContext`x, $CellContext`eyd$, D$$}, 
            Axes -> {{True, False}, {True, False}}, AxesOrigin -> {0, 0}, 
            Ticks -> {{0, 0.05, 0.1}, {50, 100, 150}}, 
            ImageSize -> {300, 150}, 
            PlotStyle -> {Blue, Dashed}]}; $CellContext`dwf8$ = {
           Point[{{D$$, $CellContext`sigma$}}]}; $CellContext`dwf9$ = {
           Point[{{
              If[
               And[D$$ >= 0, D$$ < $CellContext`eel$], 0, 
               D$$ - $CellContext`epsilon$], 0}}]}; $CellContext`dwf10$ = {
          Blue, 
           PointSize[0.03], 
           Point[{$CellContext`epl$, E$ $CellContext`epl$}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Sigma]\), \(Y\)]\)", {$CellContext`epl$ + 
             0.005, E$ $CellContext`epl$ - 10}]}; $CellContext`dwf11$ = {
          Purple, 
           PointSize[0.03], 
           
           Point[{$CellContext`ehd$, 
             50 Cos[(($CellContext`ehd$ - $CellContext`ehd$)/0.1) Pi] - 50 + 
             30 Sin[((($CellContext`ehd$ - $CellContext`eyd$)/0.18) 2) Pi] + 
             E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi]}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Sigma]\), \(u\)]\)", {$CellContext`ehd$, 
             50 Cos[(($CellContext`ehd$ - $CellContext`ehd$)/0.1) Pi] - 50 + 
             30 Sin[((($CellContext`ehd$ - $CellContext`eyd$)/0.18) 2) Pi] + 
             E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi] - 
             12}]}; $CellContext`dwf12$ = {Black, 
           PointSize[0.03], 
           
           Point[{0.1, 50 Cos[((0.1 - $CellContext`ehd$)/0.1) Pi] - 50 + 
             30 Sin[((($CellContext`ehd$ - $CellContext`eyd$)/0.18) 2) Pi] + 
             E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi]}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Sigma]\), \(f\)]\)", {
            0.1, 50 Cos[((0.1 - $CellContext`ehd$)/0.1) Pi] - 50 + 
             30 Sin[((($CellContext`ehd$ - $CellContext`eyd$)/0.18) 2) Pi] + 
             E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi] - 
             12}]}; $CellContext`dwf13$ = {Cyan, 
           PointSize[0.03], 
           
           Point[{0.1, 10 Sin[((0.1 - $CellContext`eyd$)/0.05) Pi] + 
             E$ ((0.1 - $CellContext`eyd$)/10) + E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi]}], 
           Text[
           "\!\(\*SubscriptBox[\(\[Sigma]\), \(f'\)]\)", {
            0.1, 10 Sin[((0.1 - $CellContext`eyd$)/0.05) Pi] + 
             E$ ((0.1 - $CellContext`eyd$)/10) + E$ $CellContext`epl$ + 
             5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi] - 12}]}; 
        Row[{
           
           Graphics[{$CellContext`dwf0$, $CellContext`dwf2$}, 
            PlotRange -> {{(-$CellContext`size$)/2, $CellContext`size$/
               2}, {(-1.2) $CellContext`size$, 1.2 $CellContext`size$}}, 
            ImageSize -> 100], 
           Show[
            If[
             And[D$$ >= 0, D$$ < $CellContext`epl$], $CellContext`dwf3$, 
             If[
              And[
              D$$ >= $CellContext`epl$, 
               D$$ < $CellContext`eel$], $CellContext`dwf4$, 
              If[
               And[
               D$$ >= $CellContext`eel$, 
                D$$ < $CellContext`eyd$], $CellContext`dwf5$, 
               If[
                And[
                D$$ >= $CellContext`eyd$, 
                 D$$ < $CellContext`ehd$], $CellContext`dwf6$, \
$CellContext`dwf7$]]]], Epilog -> {Red, 
              PointSize[0.03], $CellContext`dwf8$, 
              Text[
               If[D$$ < $CellContext`eel$, "Elastic", 
                If[
                 And[D$$ >= $CellContext`eel$, D$$ < $CellContext`eyd$], 
                 "Yielding", 
                 If[
                  And[D$$ >= $CellContext`eyd$, D$$ < $CellContext`ehd$], 
                  "Hardening", 
                  If[
                   And[D$$ >= $CellContext`ehd$, D$$ < 0.1], "Necking", 
                   "Failure"]]]], {0.05, 175}], 
              If[D$$ >= $CellContext`eel$, $CellContext`dwf10$], 
              If[D$$ >= $CellContext`ehd$, $CellContext`dwf11$], 
              If[D$$ == 0.1, $CellContext`dwf12$], 
              If[D$$ == 0.1, $CellContext`dwf13$], LightRed, 
              If[D$$ > $CellContext`eyd$, 
               
               Point[{D$$, 10 Sin[((D$$ - $CellContext`eyd$)/0.05) Pi] + 
                 E$ ((D$$ - $CellContext`eyd$)/10) + E$ $CellContext`epl$ + 
                 5 Sin[(($CellContext`eyd$ - $CellContext`epl$)/0.05) Pi]}]], 
              Dashed, Black, 
              Thickness[0.01], 
              If[D$$ < 0.1, 
               
               Line[{{D$$, $CellContext`sigma$}, {
                 D$$ - $CellContext`epsilon$ ($CellContext`UL$$/
                   100), $CellContext`sigma$ - $CellContext`sigma$ \
($CellContext`UL$$/100)}}], 
               
               Line[{{D$$, $CellContext`sigma$}, {
                 D$$ - $CellContext`epsilon$ (100/
                   100), $CellContext`sigma$ - $CellContext`sigma$ (100/
                   100)}}]]}, PlotRange -> {{-0.007, 0.108}, {0, 175}}]}]], 
      "Specifications" :> {{{D$$, 0.0001, 
          
          Row[{"\!\(\*\nStyleBox[\"Elongation\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Strain\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"in\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"the\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Bar\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"\
\[CurlyEpsilon]\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\"=\",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"\[CapitalDelta]L\", \"0\"],\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"/\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[SubscriptBox[\"L\", \"0\"],\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)", 
            Spacer[50]}]}, 1.*^-6, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 1}, {{$CellContext`UL$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[\"Percentage\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 0.]]\)\!\(\*\n\
StyleBox[\" \",\nFontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"of\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"Unloading\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"[\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"%\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\n\
FontFamily->\"Times New Roman\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 0.]]\)", 
            Spacer[100]}]}, 0, 100, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 2}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{694., {275., 284.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "426b6631-483c-49d0-905d-96687924b16a"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.55 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 872}, 
  WindowMargins -> {{25, Automatic}, {Automatic, 31}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 274, 8, 237, "Title"],
Cell[1763, 45, 1143, 29, 165, "Text"],
Cell[2909, 76, 229, 6, 63, "Text"],
Cell[3141, 84, 509, 11, 76, "Text"],
Cell[3653, 97, 243, 6, 63, "Text"],
Cell[3899, 105, 318, 8, 76, "Text"],
Cell[4220, 115, 33824, 640, 584, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Dw04QNhl4fJ#pBg#ZdHvYD6p *)
